@@ -26,11 +26,10 @@
 # Author: Daniele Bigoni
 #
 
+from _version import __version__
+
 import misc
 from misc import *
-import mpi_eval
-from mpi_eval import *
 
 __all__ = []
 __all__ += misc.__all__
-__all__ += mpi_eval.__all__
